pub fn evaluate_entry(entry: &ParsedCondition, ctx: &ConditionContext) -> boolExpand description
Evaluate a single condition entry. Convenience entry point used by the evaluator integration in Batch 2 and by unit tests.
pub fn evaluate_entry(entry: &ParsedCondition, ctx: &ConditionContext) -> boolEvaluate a single condition entry. Convenience entry point used by the evaluator integration in Batch 2 and by unit tests.