pub enum Decision {
Allow,
ImplicitDeny,
ExplicitDeny,
}Expand description
The result of evaluating a request against a set of policies.
Allow requires at least one matching Allow statement and zero
matching Deny statements. ExplicitDeny indicates at least one
matching Deny statement (which takes precedence over any Allow).
ImplicitDeny is the catch-all for “no policy spoke to this request”.
Variants
Implementations